This is an automated email from the ASF dual-hosted git repository.

github-merge-queue[bot] pushed a commit to branch 
gh-readonly-queue/main/pr-23659-4c20fa7b4646ac82ea1e759e76bac12fbfc03280
in repository https://gitbox.apache.org/repos/asf/datafusion.git

commit 1734d4beb4440b1cd34c4d22fbccd3ef9cac0808
Author: Jeffrey Vo <[email protected]>
AuthorDate: Sat Jul 18 12:00:07 2026 +0900

    chore: downsize `sql_planner_extended` `logical_plan_optimize` sample size 
to 5 (#23659)
    
    on my M4 Macbook pro, it estimates it would take 50 minutes (!) to run
    the benchmark
    
    ```sh
    datafusion (main)$ cargo bench -p datafusion --bench sql_planner_extended 
logical_plan
       Compiling datafusion-common v54.0.0 
(/Users/jeffrey/Code/datafusion/datafusion/common)
    ...
       Compiling datafusion v54.0.0 
(/Users/jeffrey/Code/datafusion/datafusion/core)
        Finished `bench` profile [optimized] target(s) in 8m 11s
         Running benches/sql_planner_extended.rs 
(/Users/jeffrey/.cargo_target_cache/release/deps/sql_planner_extended-c026520b80bba716)
    Gnuplot not found, using plotters backend
    Benchmarking logical_plan_optimize: Warming up for 3.0000 s
    Warning: Unable to complete 100 samples in 5.0s. You may wish to increase 
target time to 3077.4s, or reduce sample count to 10.
    Benchmarking logical_plan_optimize: Collecting 100 samples in estimated 
3077.4 s (100 iterations)
    ```
    
    and running it via the bot just times out:
    https://github.com/apache/datafusion/pull/23215#issuecomment-4995729774
    
    so might actually be useful to reduce the sample size so it can actually
    run and be of use to us
---
 datafusion/core/benches/sql_planner_extended.rs | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/datafusion/core/benches/sql_planner_extended.rs 
b/datafusion/core/benches/sql_planner_extended.rs
index b016d758f3..5bea9860c4 100644
--- a/datafusion/core/benches/sql_planner_extended.rs
+++ b/datafusion/core/benches/sql_planner_extended.rs
@@ -386,12 +386,16 @@ fn criterion_benchmark(c: &mut Criterion) {
     let df = build_test_data_frame(&baseline_ctx, &rt);
     let case_heavy_left_join_df = 
build_case_heavy_left_join_df(&case_heavy_ctx, &rt);
 
-    c.bench_function("logical_plan_optimize", |b| {
+    // really slow :(
+    let mut group = c.benchmark_group("sample_size_5");
+    group.sample_size(5);
+    group.bench_function("logical_plan_optimize", |b| {
         b.iter(|| {
             let df_clone = df.clone();
             black_box(rt.block_on(async { 
df_clone.into_optimized_plan().unwrap() }));
         })
     });
+    group.finish();
 
     c.bench_function("logical_plan_optimize_hotspot_case_heavy_left_join", |b| 
{
         b.iter(|| {


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to